#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Note PyPI 'pycxx' is a different package,
# and this package is not 'cxx' or 'CXX' on PyPI
%global modname pycxx
%{?sle15_python_module_pythons}
%define oldpython python
Name:           python-%{modname}
Version:        7.1.8
Release:        1.6
Summary:        Python extensions in C++
License:        BSD-3-Clause
Group:          Development/Libraries/Python
URL:            http://CXX.sourceforge.net/
Source0:        http://downloads.sourceforge.net/cxx/%{modname}-%{version}.tar.gz
Patch1:         python-pycxx-7.0.3-change-include-paths.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
Obsoletes:      python-cxx < %{version}
Provides:       python-cxx = %{version}
Obsoletes:      python-CXX < %{version}
Provides:       python-CXX = %{version}
BuildArch:      noarch
%ifpython2
Obsoletes:      %{oldpython}-cxx < %{version}
Provides:       %{oldpython}-cxx = %{version}
%endif
%python_subpackages

%description
PyCXX is a set of classes to help create extensions of Python in the
C++ language. The first part encapsulates the Python C API taking care
of exceptions and ref counting. The second part supports the building
of Python extension modules in C++.

%package devel
Summary:        Development files for %{modname} applications
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Obsoletes:      python-cxx-devel < %{version}
Provides:       python-cxx-devel = %{version}
Obsoletes:      python-CXX-devel < %{version}
Provides:       python-CXX-devel = %{version}
%ifpython2
Obsoletes:      %{oldpython}-cxx-devel < %{version}
Provides:       %{oldpython}-cxx-devel = %{version}
%endif

%description devel
PyCXX is a set of classes to help create extensions of Python in the
C++ language. The first part encapsulates the Python C API taking care
of exceptions and ref counting. The second part supports the building
of Python extension modules in C++.

%prep
%setup -q -n %{modname}-%{version}
%autopatch -p1

%build
%python_build
%ifpython2
rm -r Doc/Python3 && mv Doc/Python2 Doc/Python
%else
rm -r Doc/Python2 && mv Doc/Python3 Doc/Python
%endif

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%license COPYRIGHT
%doc README.html
%{python_sitelib}/CXX*

%files %{python_files devel}
%doc Doc/Python/
%{_datadir}/python%{python_bin_suffix}
%{python_sysconfig_path include}

%changelog
* Fri Mar  1 2024 Torsten Gruner <simmphonie@opensuse.org>
- update to 7.1.8
  * Add support for building against python 3.12 beta
  * _Py_PackageContext is no longer accessible.
* Wed Feb 16 2022 Dirk Müller <dmueller@suse.com>
- update to 7.1.7:
  * Add support for building against python 3.11 alpha 4.
  * Replace use of deprecated PyUnicode APIs with the supported version.
  * Add support for more number methods, like matrix and the inplace versions.
  * Use IsInstance checking so that derived classes of builtin types can be used.
  * Add support for python 3.9 beta 1 changes
  * Fix for memory leak caused by wrong ref count on python3 Py::String objects.
  * Remove support for supportPrint() etc as the tp_print field is being removed
    from python either in 3.8 or 3.9.
  * Fix problem with compiling for Python 2 and the _Py_PackageContext symbol.
  * Add exception errorType() and errorValue() function to access the type and
    value of an exception.
  * Add support for Py_LIMITED_API aka PEP-384
- drop python-pycxx-7.0.3-python37.patch python-pycxx-7.0.3-setup.py.patch (upstream)
* Mon Feb 22 2021 Markéta Machová <mmachova@suse.com>
- Drop broken %%ifpython3 macro
* Wed Jan 20 2021 John Vandenberg <jayvdb@gmail.com>
- Add note that this package is not PyPI 'pycxx'
- Fix Tumbleweed multi Python 3 builds
* Fri May 29 2020 Matej Cepl <mcepl@suse.com>
- Remove %%python3_only constructs and replace them with other
  conditional constructs.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Aug  9 2018 tchvatal@suse.com
- Add provides/obsoletes for python-CXX as pycxx is upstream name
  and name used in Fedora/Debian so we rather stick with this one
  and remove python-CXX
* Thu Aug  9 2018 tchvatal@suse.com
- Initial package, used by pysvn
- Apply patches from Fedora:
  * python-pycxx-7.0.3-python37.patch
  * python-pycxx-7.0.3-change-include-paths.patch
  * python-pycxx-7.0.3-setup.py.patch
